==> phpMyGPX-0.2.tar.bz2: phpmygpx/export.php <==
<?php
/**
* @version $Id: $
* @package osm-things
* @copyright Copyright (C) 2008 Sebastian Klemm.
* @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
*/

define( '_VALID_OSM', TRUE );
define( '_PATH', './' );
$DEBUG = TRUE;
if($DEBUG) error_reporting(E_ALL);
setlocale (LC_TIME, "ge", "de_DE.UTF-8");	# german

include("./config.inc.php");
include("./libraries/functions.inc.php");
#include("./libraries/classes.php");

$name = strip_tags($_GET['name']);
$option = strip_tags($_GET['option']);
$f_date = strip_tags($_GET['date']);
$f_lat = intval($_GET['lat']);
$f_lon = intval($_GET['lon']);
$f_lat_range = intval($_GET['lat_range']);
$f_lon_range = intval($_GET['lon_range']);

// connect to database
$link = db_connect_h($cfg['db_host'], $cfg['db_name'], $cfg['db_user'], $cfg['db_password']);

if($name) {
	header("Content-type: text/xml");
	header('Content-Disposition: attachment; filename="'.$name.'.gpx"');

	$query = "SELECT SQL_CALC_FOUND_ROWS *, 
			DATE(`timestamp`) AS 'date', TIME(`timestamp`) AS 'time' FROM `gpx_import` ";
	$query .= "WHERE 1 ";
	if($f_date)
		$query .= "AND DATE(`timestamp`) = '$f_date' ";
	if($f_lat)
		$query .= "AND `latitude` BETWEEN '$f_lat'-'$f_lat_range' 
				AND '$f_lat'+'$f_lat_range' ";
	if($f_lon)
		$query .= "AND `longitude` BETWEEN '$f_lon'-'$f_lon_range' 
				AND '$f_lon'+'$f_lon_range' ";

    $result = db_query($query);
	#if($DEBUG)	out($query, 'OUT_DEBUG');
    if(mysql_num_rows($result)) {
		$num_found = mysql_result(db_query("SELECT FOUND_ROWS();") ,0);
		writeGpxHeader();
		while($row = mysql_fetch_array($result, MYSQL_ASSOC)) {
			writeGpxRow($row);
		}
		writeGpxFooter();
	}
}


function writeGpxHeader() {
	$str = <<<GPX_H
<?xml version="1.0" encoding="utf-8"?>
<gpx version="1.1" creator="OSM-Things"
        xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
        xmlns="http://www.topografix.com/GPX/1.1"
        xsi:schemaLocation="http://www.topografix.com/GPS/1/1
        http://www.topografix.com/GPX/1/1/gpx.xsd">
  <metadata>
    <name>OSM-Things</name>
    <author>Sebastian Klemm (sebastian.klemm@planet-interkom.de)</author>
    <copyright>GPL-2</copyright>
  </metadata>
  <trk>
    <trkseg>
GPX_H;
	echo $str ."\n";
}

function writeGpxRow($tp) {
	echo '      <trkpt lat="'.($tp['latitude']/1000000).'" lon="'.($tp['longitude']/1000000)."\">\n";
	echo "        <time>".$tp['date']."T".$tp['time'].".00Z</time>\n";
	echo "      </trkpt>\n";
}

function writeGpxFooter() {
	$str = <<<GPX_F
    </trkseg>
  </trk>
</gpx>
GPX_F;
	echo $str;
}
?>

==> phpMyGPX-0.3.1.tar.bz2: phpmygpx/export.php <==
<?php
/**
* @version $Id: $
* @package osm-things
* @copyright Copyright (C) 2008 Sebastian Klemm.
* @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
*/

define( '_VALID_OSM', TRUE );
define( '_PATH', './' );
$DEBUG = FALSE;
if($DEBUG) error_reporting(E_ALL);
setlocale (LC_TIME, "ge", "de_DE.UTF-8");	# german

include("./config.inc.php");
include("./libraries/functions.inc.php");

$name = strip_tags($_GET['name']);
$option = strip_tags($_GET['option']);
$f_date = strip_tags($_GET['date']);
$f_lat = intval($_GET['lat']);
$f_lon = intval($_GET['lon']);
$f_lat_range = intval($_GET['lat_range']);
$f_lon_range = intval($_GET['lon_range']);

// connect to database
$link = db_connect_h($cfg['db_host'], $cfg['db_name'], $cfg['db_user'], $cfg['db_password']);

if($name) {
	header("Content-type: text/xml");
	header('Content-Disposition: attachment; filename="'.$name.'.gpx"');

	$query = "SELECT SQL_CALC_FOUND_ROWS *, 
			DATE(`timestamp`) AS 'date', TIME(`timestamp`) AS 'time' FROM `gpx_import` ";
	$query .= "WHERE 1 ";
	if($f_date)
		$query .= "AND DATE(`timestamp`) = '$f_date' ";
	if($f_lat)
		$query .= "AND `latitude` BETWEEN '$f_lat'-'$f_lat_range' 
				AND '$f_lat'+'$f_lat_range' ";
	if($f_lon)
		$query .= "AND `longitude` BETWEEN '$f_lon'-'$f_lon_range' 
				AND '$f_lon'+'$f_lon_range' ";

    $result = db_query($query);
	#if($DEBUG)	out($query, 'OUT_DEBUG');
    if(mysql_num_rows($result)) {
		$num_found = mysql_result(db_query("SELECT FOUND_ROWS();") ,0);
		writeGpxHeader();
		while($row = mysql_fetch_array($result, MYSQL_ASSOC)) {
			writeGpxRow($row);
		}
		writeGpxFooter();
	}
}


function writeGpxHeader() {
	$str = <<<GPX_H
<?xml version="1.0" encoding="utf-8"?>
<gpx version="1.1" creator="phpMyGPX"
        xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
        xmlns="http://www.topografix.com/GPX/1.1"
        xsi:schemaLocation="http://www.topografix.com/GPS/1/1
        http://www.topografix.com/GPX/1/1/gpx.xsd">
  <metadata>
    <name>phpMyGPX</name>
    <author>phpMyGPX web application by S. Klemm</author>
    <copyright>GPL-2</copyright>
    <link>http://osm.erlkoenigkabale.eu/</link>
  </metadata>
  <trk>
    <trkseg>
GPX_H;
	echo $str ."\n";
}

function writeGpxRow($tp) {
	echo '      <trkpt lat="'.($tp['latitude']/1000000).'" lon="'.($tp['longitude']/1000000)."\">\n";
	echo "        <time>".$tp['date']."T".$tp['time'].".00Z</time>\n";
	echo "      </trkpt>\n";
}

function writeGpxFooter() {
	$str = <<<GPX_F
    </trkseg>
  </trk>
</gpx>
GPX_F;
	echo $str;
}
?>
